Hi Andrew/Linus, >From original message (by Randy Dunlap): "Reduce local variable (large struct) stack usage in zoran_do_ioctl() from 1028 bytes to 324 bytes (on x86-32) by declaring & using only 1 "struct zoran_jpg_settings" instead of 5 instances of it. Reduced from 5 * 180 bytes to 1 * 180 bytes, plus other locals in each case." Signed-off-by: Randy Dunlap Signed-off-by: Ronald S. Bultje Regards, Ronald -- Ronald S. Bultje